@@ -1,4 +1,4 @@
-"""Validators for Django model fields"""
+"""Validators for Django model fields."""
 
 
 # Built-in
@@ -11,14 +11,14 @@ from django.utils.deconstruct import deconstructible
 
 @deconstructible
 class LengthValidator:
-    """Validator that can check the min and/or max length of a field"""
+    """Validator that can check the min and/or max length of a field."""
 
     message: str = ""  # Depends on args
 
     def __init__(
         self, min_: Optional[int] = None, max_: Optional[int] = None, trim: bool = True
     ) -> None:
-        """Sets the instance attributes"""
+        """Sets the instance attributes."""
         if min_ is None and max_ is None:
             raise ValueError("You need to provide at least a min or max length")
         self.min_: Optional[int] = min_
@@ -26,7 +26,7 @@ class LengthValidator:
         self.trim: bool = trim
 
     def __call__(self, value: str) -> None:
-        """Checks if the value meets the length criterion"""
+        """Checks if the value meets the length criterion."""
         if self.trim:
             value = value.strip()
         length = len(value)
