@@ -1,8 +1,8 @@
-"""Decorators for django"""
+"""Decorators for django."""
 
 
 # Built-in
-from typing import Callable
+from typing import Any, Callable
 
 # Django
 from django.http import HttpRequest, HttpResponse, HttpResponseRedirect
@@ -10,13 +10,11 @@ from django.shortcuts import render
 
 
 def render_to(template: str) -> Callable:
-    """
-    Decorator that renders a django view to a specific template
-    Functions using the decorator must simply return the context dict
-    """
+    """Decorator that renders a django view to a specific template Functions
+    using the decorator must simply return the context dict."""
 
     def renderer(function: Callable) -> Callable:
-        def wrapper(request: HttpRequest, *args, **kwargs) -> HttpResponse:
+        def wrapper(request: HttpRequest, *args: Any, **kwargs: Any) -> HttpResponse:
             response: HttpResponse = function(request, *args, **kwargs)
             if isinstance(response, (HttpResponse, HttpResponseRedirect)):
                 return response
